import { defineConfig } from 'vite'
import vue from '@vitejs/plugin-vue'
import { resolve, join } from 'path'
import fs from 'fs/promises'
import AutoImport from 'unplugin-auto-import/vite'
import Components from 'unplugin-vue-components/vite'
import { ElementPlusResolver } from 'unplugin-vue-components/resolvers'

// const putDir = 'school_service/'
// https://vitejs.dev/config/
export default defineConfig(async () => {
  const input = {}
  await fs.readdir(join(__dirname, 'page')).then((res) => {
    // console.dir(res)
    res.forEach((file) => {
      const [filename, ext] = file.split('.')
      if (ext === 'html') {
        input[filename] = resolve(__dirname, `page/${file}`)
      }
    })
  })
  return {
    resolve: {
      alias: {
        '@': resolve(__dirname, './src'),
        '@c': resolve(__dirname, './src/components'),
        '@u': resolve(__dirname, './src/utils'),
        '@s': resolve(__dirname, './src/stores'),
      },
    },
    plugins: [
      vue(),
      AutoImport({
        resolvers: [ElementPlusResolver()],
      }),
      Components({
        resolvers: [ElementPlusResolver()],
      }),
    ],
    build: {
      assetsDir: 'src/multi',
      rollupOptions: {
        input,
      },
    },
    css: {
      preprocessorOptions: {
        scss: {
          charset: false,
        }
      },
    },
    base:'/'
  }
})
